<ResourceDictionary xmlns="http://schemas.microsoft.com/winfx/2006/xaml/presentation" xmlns:x="http://schemas.microsoft.com/winfx/2006/xaml" xmlns:system="clr-namespace:System;assembly=mscorlib">
    <system:String x:Key="hello_world">Hello World!</system:String>
    <system:String x:Key="resource_key">Translated value.</system:String>
</ResourceDictionary>
