# Copyright © Michal Čihař <michal@weblate.org>
#
# SPDX-License-Identifier: GPL-3.0-or-later

# Generated by Django 4.1a1 on 2022-05-19 11:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("trans", "0150_convert_context"),
    ]

    operations = [
        migrations.AddField(
            model_name="project",
            name="machinery_settings",
            field=models.JSONField(default=dict, blank=True),
        ),
    ]
