# Copyright © Michal Čihař <michal@weblate.org>
#
# SPDX-License-Identifier: GPL-3.0-or-later

# Generated by Django 4.0.6 on 2022-11-29 18:42

from django.conf import settings
from django.db import migrations, models

import weblate.utils.validators


class Migration(migrations.Migration):

    dependencies = [
        ("trans", "0160_alter_change_index_together"),
    ]

    operations = [
        migrations.AlterField(
            model_name="project",
            name="name",
            field=models.CharField(
                help_text="Display name",
                max_length=60,
                unique=True,
                validators=[weblate.utils.validators.validate_project_name],
                verbose_name="Project name",
            ),
        ),
        migrations.AlterField(
            model_name="project",
            name="web",
            field=models.URLField(
                help_text="Main website of translated project.",
                validators=[weblate.utils.validators.validate_project_web],
                verbose_name="Project website",
                blank=not settings.WEBSITE_REQUIRED,
            ),
        ),
    ]
