# Copyright © Michal Čihař <michal@weblate.org>
#
# SPDX-License-Identifier: GPL-3.0-or-later

# Generated by Django 3.2 on 2022-02-23 07:33

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("wladmin", "0004_alter_backupservice_repository"),
    ]

    operations = [
        migrations.AlterField(
            model_name="backuplog",
            name="event",
            field=models.CharField(
                choices=[
                    ("backup", "Backup performed"),
                    ("error", "Backup failed"),
                    ("prune", "Deleted the oldest backups"),
                    ("cleanup", "Cleaned up backup storage"),
                    ("init", "Repository initialization"),
                ],
                db_index=True,
                max_length=100,
            ),
        ),
    ]
