# Copyright © Michal Čihař <michal@weblate.org>
#
# SPDX-License-Identifier: GPL-3.0-or-later

# Generated by Django 4.1b1 on 2022-07-18 12:46

from django.db import migrations


def rename_java_language(apps, schema_editor):
    Component = apps.get_model("trans", "Component")

    Component.objects.using(schema_editor.connection.alias).filter(
        language_code_style="java"
    ).update(language_code_style="bcp_legacy")


class Migration(migrations.Migration):

    dependencies = [
        ("trans", "0152_alter_change_action"),
    ]

    operations = [migrations.RunPython(rename_java_language, elidable=True)]
