# Copyright © Michal Čihař <michal@weblate.org>
#
# SPDX-License-Identifier: GPL-3.0-or-later

from django.utils.translation import gettext_lazy

COLOR_CHOICES = (
    # Translators: Name of a color
    ("navy", gettext_lazy("Navy")),
    # Translators: Name of a color
    ("blue", gettext_lazy("Blue")),
    # Translators: Name of a color
    ("aqua", gettext_lazy("Aqua")),
    # Translators: Name of a color
    ("teal", gettext_lazy("Teal")),
    # Translators: Name of a color
    ("olive", gettext_lazy("Olive")),
    # Translators: Name of a color
    ("green", gettext_lazy("Green")),
    # Translators: Name of a color
    ("lime", gettext_lazy("Lime")),
    # Translators: Name of a color
    ("yellow", gettext_lazy("Yellow")),
    # Translators: Name of a color
    ("orange", gettext_lazy("Orange")),
    # Translators: Name of a color
    ("red", gettext_lazy("Red")),
    # Translators: Name of a color
    ("maroon", gettext_lazy("Maroon")),
    # Translators: Name of a color
    ("fuchsia", gettext_lazy("Fuchsia")),
    # Translators: Name of a color
    ("purple", gettext_lazy("Purple")),
    # Translators: Name of a color
    ("black", gettext_lazy("Black")),
    # Translators: Name of a color
    ("gray", gettext_lazy("Gray")),
    # Translators: Name of a color
    ("silver", gettext_lazy("Silver")),
)
