{% load i18n %}

<div class="form-group">
  <label>{% trans "Generated strings" %}</label>

  <p>
    {% trans "The strings will be generated using following pattern:" %}
  </p>

  <p>
    <span class="badge">{% trans "Fixed string prefix" %}</span>
    <span class="badge">{% trans "Variable string prefix" %}</span>
    <span class="badge">{% trans "Source string" %}</span>
    <span class="badge">{% trans "Variable string suffix" %}</span>
    <span class="badge">{% trans "Fixed string suffix" %}</span>
  </p>

</div>
