# Copyright © Michal Čihař <michal@weblate.org>
#
# SPDX-License-Identifier: GPL-3.0-or-later

# Generated by Django 4.0.2 on 2022-03-03 09:33

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("weblate_auth", "0022_alter_user_managers"),
    ]

    operations = [
        migrations.AddField(
            model_name="user",
            name="is_bot",
            field=models.BooleanField(
                db_index=True, default=False, verbose_name="Robot user"
            ),
        ),
        migrations.AddField(
            model_name="user",
            name="date_expires",
            field=models.DateTimeField(
                blank=True, default=None, null=True, verbose_name="Expires"
            ),
        ),
    ]
