# Copyright © Michal Čihař <michal@weblate.org>
#
# SPDX-License-Identifier: GPL-3.0-or-later

# Generated by Django 4.1.3 on 2022-12-13 10:24

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("weblate_auth", "0024_bot_users"),
    ]

    operations = [
        migrations.AddField(
            model_name="group",
            name="admins",
            field=models.ManyToManyField(
                blank=True,
                help_text="The administrator can add or remove users from a team.",
                related_name="administered_group_set",
                to=settings.AUTH_USER_MODEL,
                verbose_name="Team administrators",
            ),
        ),
    ]
