# Copyright © Michal Čihař <michal@weblate.org>
#
# SPDX-License-Identifier: GPL-3.0-or-later

# Generated by Django 3.2 on 2021-05-16 18:37

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("trans", "0134_component_remote_revision"),
    ]

    operations = [
        migrations.AddField(
            model_name="component",
            name="local_revision",
            field=models.CharField(blank=True, default="", max_length=200),
        ),
    ]
