# Copyright © Michal Čihař <michal@weblate.org>
#
# SPDX-License-Identifier: GPL-3.0-or-later

# Generated by Django 4.0 on 2021-12-20 12:23

from django.db import migrations

import weblate.trans.models.unit


class Migration(migrations.Migration):

    dependencies = [
        ("trans", "0142_projecttoken"),
    ]

    operations = [
        migrations.AlterField(
            model_name="unit",
            name="labels",
            field=weblate.trans.models.unit.LabelsField(
                blank=True, to="trans.Label", verbose_name="Labels"
            ),
        ),
    ]
