{% load i18n %}

{% if group.project_selection == 1 %}
  <em>{% trans "All projects" %}</em>
{% elif group.project_selection == 3 %}
  <em>{% trans "All public projects" %}</em>
{% elif group.project_selection == 4 %}
  <em>{% trans "All protected projects" %}</em>
{% else %}
  {% for project in group.projects.all %}
    <span class="badge">{{ project }}</span>
  {% endfor %}
{% endif %}
