{% load i18n %}
<p>{% trans "This component is set up incorrectly." %}</p>

<p>{% trans "Following enforced checks are not used anywhere:" %}</p>

<ul>
  {% for check in component.get_unused_enforcements %}
    {% if check.notsupported %}
      <li>{% blocktrans with check=check.name %}{{ check }} quality check is enforced, but it is not available.{% endblocktrans %}</li>
    {% else %}
      <li>{% blocktrans with check=check.name flag=check.enable_string %}{{ check }} quality check is enforced, but not turned on using <code>{{ flag }}</code> flag.{% endblocktrans %}</li>
    {% endif %}
  {% endfor %}
</ul>

<p>
  {% trans "The check can be turned on by adding the corresponding flag to string or component flags." %}
</p>
