<a href="{{ screenshot.image.url }}" class="thumbnail" title="{{ screenshot.name }}" data-details-url="{% url 'screenshot' pk=screenshot.pk %}"{% if user_can_edit_screenshot %} data-can-edit{% endif %}><img class="img-responsive" src="{{ screenshot.image.url }}" alt="{{ screenshot.name }}" /></a>
