{% load i18n %}
{% load translations %}

<p>{% trans "Weblate could not push changes to the upstream repository." %}</p>

<pre>{{ error }}</pre>

{% if analysis.terminal %}
  <p>{% trans "Your push URL seems to miss credentials. Either provide them in the URL or use SSH with key based authentication." %}</p>
{% endif %}

{% if analysis.repo_suggestion %}
  <p>{% trans "You might want to use following URL instead:" %} <code>{{ analysis.repo_suggestion }}</code></p>
{% endif %}

{% if analysis.force_push_suggestion %}
  <p>
    {% trans "You might want to choose Git with force push as version control system in the component configuration to overwrite the remote repository after rebasing commits in Weblate." %}
  </p>
{% elif analysis.behind %}
  <p>
    {% trans "The Weblate repository is missing some commits from upstream. Perhaps it is not receiving notifications upon updates of the remote repository." %}
  </p>
{% endif %}
