# Copyright © Michal Čihař <michal@weblate.org>
#
# SPDX-License-Identifier: GPL-3.0-or-later

# Generated by Django 4.1.3 on 2023-01-18 09:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("accounts", "0021_profile_commit_email_verifiedemail_is_deliverable"),
    ]

    operations = [
        migrations.AlterField(
            model_name="profile",
            name="linkedin",
            field=models.SlugField(
                allow_unicode=True,
                blank=True,
                db_index=False,
                help_text="Your LinkedIn profile name from linkedin.com/in/profilename",
                verbose_name="LinkedIn profile name",
            ),
        ),
    ]
