# Copyright © Michal Čihař <michal@weblate.org>
#
# SPDX-License-Identifier: GPL-3.0-or-later

# Generated by Django 3.2.6 on 2021-11-26 19:27

import django.core.validators
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("trans", "0140_fix_commit_age"),
    ]

    operations = [
        migrations.AlterField(
            model_name="component",
            name="commit_pending_age",
            field=models.SmallIntegerField(
                default=settings.COMMIT_PENDING_HOURS,
                help_text="Time in hours after which any pending changes will be committed to the VCS.",
                validators=[django.core.validators.MaxValueValidator(2160)],
                verbose_name="Age of changes to commit",
            ),
        ),
    ]
