# Copyright © Michal Čihař <michal@weblate.org>
#
# SPDX-License-Identifier: GPL-3.0-or-later

# Generated by Django 4.0.2 on 2022-03-03 12:44

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("trans", "0146_alter_component_merge_style"),
        ("weblate_auth", "0024_bot_users"),
    ]

    operations = [
        migrations.DeleteModel(
            name="ProjectToken",
        ),
    ]
