# Copyright © Michal Čihař <michal@weblate.org>
#
# SPDX-License-Identifier: GPL-3.0-or-later

# Generated by Django 4.0.2 on 2022-04-14 07:58

from django.conf import settings
from django.db import migrations, models

import weblate.utils.render


class Migration(migrations.Migration):

    dependencies = [
        ("trans", "0148_alter_component_language_code_style"),
    ]

    operations = [
        migrations.AddField(
            model_name="component",
            name="pull_message",
            field=models.TextField(
                default=settings.DEFAULT_PULL_MESSAGE,
                help_text="You can use template language for various info, please consult the documentation for more details.",
                validators=[weblate.utils.render.validate_render_addon],
                verbose_name="Merge request message",
            ),
        ),
    ]
